@@ -1,3 +1,19 @@
+# Copyright 2022 c0fec0de
+#
+# This file is part of Git Workspace.
+#
+# Git Workspace is free software: you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License as published by the Free 
+# Software Foundation, either version 3 of the License, or (at your option) any
+# later version.
+#
+# Git Workspace is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License along
+# with Git Workspace. If not, see <https://www.gnu.org/licenses/>.
+
 """
 Multi Repository Management.
 
@@ -220,12 +236,13 @@ class GitWS:
         project_paths=None,
         manifest_path: Path = None,
         groups: Groups = None,
+        branch: bool = False,
     ) -> Generator[Status, None, None]:
         """Iterate over Status."""
         for clone in self._foreach(project_paths=project_paths, manifest_path=manifest_path, groups=groups):
             path = clone.git.path
             self._check_clone(clone)
-            for status in clone.git.status():
+            for status in clone.git.status(branch=branch):
                 yield status.with_path(path)
 
     def checkout(self, paths: Tuple[Path, ...]):
